# Generated by roxygen2: do not edit by hand

export(BulkPhyloExpressionSet)
export(BulkPhyloExpressionSet_from_df)
export(COUNT_TRANSFORMS)
export(ConservationTestResult)
export(PS_colours)
export(PhyloExpressionSetBase)
export(ScPhyloExpressionSet)
export(ScPhyloExpressionSet_from_matrix)
export(ScPhyloExpressionSet_from_seurat)
export(TAI)
export(TDI)
export(TEI)
export(TPI)
export(TXI)
export(TXI_conf_int)
export(TXI_std_dev)
export(TestResult)
export(age.apply)
export(as_BulkPhyloExpressionSet)
export(as_data_frame)
export(check_BulkPhyloExpressionSet)
export(check_PhyloExpressionSet)
export(check_ScPhyloExpressionSet)
export(collapse)
export(destroy_pattern)
export(diagnose_test_robustness)
export(distributions)
export(downsample)
export(downsample_expression)
export(exp_p)
export(gatai_animate_destruction)
export(genes_lowly_expressed)
export(genes_top_expr)
export(genes_top_mean)
export(genes_top_variance)
export(get_phylomap)
export(get_strata_legend)
export(match_map)
export(match_map_sc_matrix)
export(match_map_sc_seurat)
export(normalise_stage_expression)
export(omit_matrix)
export(pTXI)
export(permute_PS)
export(plot_contribution)
export(plot_cullen_frey)
export(plot_distribution_expression)
export(plot_distribution_pTAI)
export(plot_distribution_pTAI_qqplot)
export(plot_distribution_strata)
export(plot_gatai_results)
export(plot_gene_heatmap)
export(plot_gene_profiles)
export(plot_gene_space)
export(plot_mean_var)
export(plot_null_txi_sample)
export(plot_relative_expression_bar)
export(plot_relative_expression_line)
export(plot_sample_space)
export(plot_signature)
export(plot_signature_gene_quantiles)
export(plot_signature_multiple)
export(plot_signature_transformed)
export(plot_strata_expression)
export(quantile_rank)
export(rel_exp_matrix)
export(relative_expression)
export(remove_genes)
export(rename_phyex_set)
export(sTXI)
export(save_gatai_results_pdf)
export(select_genes)
export(set_expression)
export(stat_early_conservation_test)
export(stat_flatline_test)
export(stat_late_conservation_test)
export(stat_pairwise_test)
export(stat_reductive_hourglass_test)
export(stat_reverse_hourglass_test)
export(strata_enrichment)
export(taxid)
export(tf)
export(tf_PS)
export(tf_stability)
export(transform_counts)
import(RColorBrewer)
import(S7)
import(dplyr)
import(ggplot2)
import(patchwork)
import(purrr)
import(tibble)
import(tidyr)
importFrom(RColorBrewer,brewer.pal)
importFrom(RColorBrewer,brewer.pal.info)
importFrom(Rcpp,sourceCpp)
importFrom(dplyr,bind_rows)
importFrom(dplyr,case_when)
importFrom(dplyr,filter)
importFrom(dplyr,group_by)
importFrom(dplyr,inner_join)
importFrom(dplyr,left_join)
importFrom(dplyr,mutate)
importFrom(dplyr,relocate)
importFrom(dplyr,summarise)
importFrom(ggforce,geom_sina)
importFrom(ggrepel,geom_text_repel)
importFrom(ggridges,geom_density_ridges)
importFrom(grDevices,colorRampPalette)
importFrom(graphics,plot.new)
importFrom(graphics,text)
importFrom(graphics,title)
importFrom(memoise,memoise)
importFrom(purrr,map)
importFrom(stats,density)
importFrom(stats,kruskal.test)
importFrom(stats,ks.test)
importFrom(stats,qqplot)
importFrom(stats,quantile)
importFrom(stats,setNames)
importFrom(tibble,rowid_to_column)
importFrom(tibble,rownames_to_column)
importFrom(tibble,tibble)
importFrom(tidyr,pivot_longer)
importFrom(utils,read.table)
useDynLib(myTAI, .registration = TRUE)
