---
title: "Break TAI patterns using gaTAI"
output: rmarkdown::html_vignette
vignette: >
  %\VignetteIndexEntry{Break TAI patterns using gaTAI}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

## Motivation for breaking the hourglass

Inspired by the 'ontogeny-phylogeny' correlations and the hourglass model of evolutionary development, we recently asked whether we could break the hourglass or any TAI profile by extracting a stable set of genes, and gain information about the role these extracted genes have in the development of the organism.

Further motivation is in [this thesis](https://dspace.cuni.cz/handle/20.500.11956/193428).

## Break the hourglass using gaTAI

```{r message = FALSE}
library(myTAI)
data("example_phyex_set")
```

```{r message = FALSE, eval = FALSE}
myTAI::destroy_pattern(example_phyex_set)
```

...

:::{.note}
This is a teaser.

The `myTAI::destroy_pattern()` requires the package `gataiR` which is still under development.
:::